# PersonV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV20**](LastModifiedDateV20.md) |  | [optional] 
**name** | [**NameV20**](NameV20.md) |  | [optional] 
**other_names** | [**OtherNamesV20**](OtherNamesV20.md) |  | [optional] 
**biography** | [**BiographyV20**](BiographyV20.md) |  | [optional] 
**researcher_urls** | [**ResearcherUrlsV20**](ResearcherUrlsV20.md) |  | [optional] 
**emails** | [**EmailsV20**](EmailsV20.md) |  | [optional] 
**addresses** | [**AddressesV20**](AddressesV20.md) |  | [optional] 
**keywords** | [**KeywordsV20**](KeywordsV20.md) |  | [optional] 
**external_identifiers** | [**PersonExternalIdentifiersV20**](PersonExternalIdentifiersV20.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

